==> rdc_flutter_sdk-0.0.11.tar.gz: lib/src/controllers/condition_controller.dart <==
import 'dart:async';

import 'package:battery_plus/battery_plus.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/src/controllers/rabbit_config_controller.dart';
import 'package:rdc_flutter_sdk/src/util/battery_helper.dart';
import 'package:rdc_flutter_sdk/src/util/cpu_helper.dart';
import 'package:rdc_flutter_sdk/src/util/memory_helper.dart';
import 'package:disk_space/disk_space.dart';
import 'package:rxdart/rxdart.dart';

class ConditionController {
  final RabbitConfigController _config = Get.find(tag: 'rdc_flutter_sdk');
  final Battery _battery = Battery();

  var currentCpu = 0;
  var currentBattery = 0;
  var currentMemory = 0;
  var currentFreeSpace = 0.0;

  var _maxFrequency = 0;
  var _sumFrequency = 0;

  var condition = BehaviorSubject.seeded(
      {'cpu': 0, 'memory': 0, 'battery': 0, 'freeSpace': 0.0});

  ConditionController();

  Future<ConditionController> init() async {
    if (GetPlatform.isAndroid) {
      CpuInfo cpuInfo = await CpuReader.cpuInfo;
      //print('Number of Cores ${cpuInfo.numberOfCores}');
      _maxFrequency = 0;
      var minMax = cpuInfo.minMaxFrequencies;
      for (var m in minMax.entries) {
        //print('key ${m.key}, min ${m.value.min}, max = ${m.value.max}');
        _maxFrequency += int.parse(m.value.max.toString());
      }
    }

    await getBetterLevel();
    await getCpu();
    await getUsedMemorySize();
    await getStorageSize();
    intervalCondition();
    return this;
  }

  void intervalCondition() {
    Timer.periodic(const Duration(milliseconds: 500), (timer) async {
      await Future.wait(
          [getBetterLevel(), getCpu(), getUsedMemorySize(), getStorageSize()]);
      condition.add({
        'cpu': currentCpu,
        'memory': currentMemory,
        'battery': currentBattery,
        'freeSpace': currentFreeSpace
      });
    });
  }

  Future<void> getBetterLevel() async {
    try {
      if (GetPlatform.isAndroid) {
        currentBattery = await _battery.batteryLevel;
        //print('isAndroid currentBattery : $currentBattery');
      } else if (GetPlatform.isIOS) {
        currentBattery = (await BatterReader.batteryPercent).toInt();
        //print('isIOS currentBattery : $currentBattery');
      }
    } catch (_) {}
  }

  Future<void> getCpu() async {
    if (GetPlatform.isAndroid) {
      CpuInfo cpuInfo = await CpuReader.cpuInfo;
      //print('Number of Cores ${cpuInfo.numberOfCores}');
      _sumFrequency = 0;
      for (int i = 0; i < cpuInfo.numberOfCores; i++) {
        var freq = await CpuReader.getCurrentFrequency(i);
        // print('Core number ${i + 1} freq ${freq} Mhz');
        _sumFrequency += freq;
      }

      // print('getCpu $_sumFrequency : $_maxFrequency');
      var maxFre = _maxFrequency == 0 ? 1 : _maxFrequency;
      var sumFre = _sumFrequency == 0 ? 1 : _sumFrequency;

      if (maxFre == 1 || sumFre == 1) {
        currentCpu = 0;
      } else {
        currentCpu = (sumFre * 100) ~/ maxFre;
      }

      currentCpu = currentCpu > 100 ? 100 : currentCpu;
      //print('Current Cpu load $currentCpu %');
    } else if (GetPlatform.isIOS) {
      currentCpu = (await CpuReader.cpuUsage).toInt();
    }
  }

  Future<void> getUsedMemorySize() async {
    if (GetPlatform.isAndroid) {
      var memory = await MemoryReader.memoryUsed;
      //print('Memory load ${memory.loadMem} %');
      currentMemory = (memory.loadMem ?? 0).toInt();
    } else if (GetPlatform.isIOS) {
      currentMemory = (await MemoryReader.totalUsagePercent).toInt();
      //print('Memory load $percent %');
    }
  }

  Future<Map<String, bool>> checkSend() async {
    var cpu = true;
    var memory = true;
    var battery = true;
    // check battery
    if (_config.batteryLevel != 0) {
      await getBetterLevel();
      battery = currentBattery >= _config.batteryLevel;
    }

    // check cpu load
    if (_config.cpu != 0) {
      await getCpu();
      cpu = currentCpu <= _config.cpu;
    }

    // check cpu load
    if (_config.memory != 0) {
      await getUsedMemorySize();
      memory = currentMemory <= _config.memory;
    }

    return {
      'cpu $currentCpu% > ${_config.cpu}': cpu,
      'memory $currentMemory% > ${_config.memory} ': memory,
      'battery $currentBattery% < ${_config.batteryLevel}': battery
    };
  }

  Future<void> getStorageSize() async {
    //var total = await DiskSpace.getTotalDiskSpace ?? 0;
    var free = await DiskSpace.getFreeDiskSpace ?? 0;
    currentFreeSpace = free;

    //print('total : $total, free : $free, currentFreeSpace : $currentFreeSpace');
  }
}

==> rdc_flutter_sdk-0.0.20-dev.tar.gz: lib/src/controllers/condition_controller.dart <==
import 'dart:async';

import 'package:battery_plus/battery_plus.dart';
import 'package:disk_space_plus/disk_space_plus.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/src/controllers/rabbit_config_controller.dart';
import 'package:rdc_flutter_sdk/src/util/battery_helper.dart';
import 'package:rdc_flutter_sdk/src/util/cpu_helper.dart';
import 'package:rdc_flutter_sdk/src/util/memory_helper.dart';

import 'package:rxdart/rxdart.dart';

class ConditionController {
  final RabbitConfigController _config = Get.find(tag: 'rdc_flutter_sdk');
  final Battery _battery = Battery();

  var currentCpu = 0;
  var currentBattery = 0;
  var currentMemory = 0;
  var currentFreeSpace = 0.0;

  var _maxFrequency = 0;
  var _sumFrequency = 0;

  var condition = BehaviorSubject.seeded(
      {'cpu': 0, 'memory': 0, 'battery': 0, 'freeSpace': 0.0});

  ConditionController();

  Future<ConditionController> init() async {
    if (GetPlatform.isAndroid) {
      CpuInfo cpuInfo = await CpuReader.cpuInfo;
      //print('Number of Cores ${cpuInfo.numberOfCores}');
      _maxFrequency = 0;
      var minMax = cpuInfo.minMaxFrequencies;
      for (var m in minMax.entries) {
        //print('key ${m.key}, min ${m.value.min}, max = ${m.value.max}');
        _maxFrequency += int.parse(m.value.max.toString());
      }
    }

    await getBetterLevel();
    await getCpu();
    await getUsedMemorySize();
    await getStorageSize();
    intervalCondition();
    return this;
  }

  void intervalCondition() {
    Timer.periodic(const Duration(milliseconds: 500), (timer) async {
      await Future.wait(
          [getBetterLevel(), getCpu(), getUsedMemorySize(), getStorageSize()]);
      condition.add({
        'cpu': currentCpu,
        'memory': currentMemory,
        'battery': currentBattery,
        'freeSpace': currentFreeSpace
      });
    });
  }

  Future<void> getBetterLevel() async {
    try {
      if (GetPlatform.isAndroid) {
        currentBattery = await _battery.batteryLevel;
        //print('isAndroid currentBattery : $currentBattery');
      } else if (GetPlatform.isIOS) {
        currentBattery = (await BatterReader.batteryPercent).toInt();
        //print('isIOS currentBattery : $currentBattery');
      }
    } catch (_) {}
  }

  Future<void> getCpu() async {
    if (GetPlatform.isAndroid) {
      CpuInfo cpuInfo = await CpuReader.cpuInfo;
      //print('Number of Cores ${cpuInfo.numberOfCores}');
      _sumFrequency = 0;
      for (int i = 0; i < cpuInfo.numberOfCores; i++) {
        var freq = await CpuReader.getCurrentFrequency(i);
        // print('Core number ${i + 1} freq ${freq} Mhz');
        _sumFrequency += freq;
      }

      // print('getCpu $_sumFrequency : $_maxFrequency');
      var maxFre = _maxFrequency == 0 ? 1 : _maxFrequency;
      var sumFre = _sumFrequency == 0 ? 1 : _sumFrequency;

      if (maxFre == 1 || sumFre == 1) {
        currentCpu = 0;
      } else {
        currentCpu = (sumFre * 100) ~/ maxFre;
      }

      currentCpu = currentCpu > 100 ? 100 : currentCpu;
      //print('Current Cpu load $currentCpu %');
    } else if (GetPlatform.isIOS) {
      currentCpu = (await CpuReader.cpuUsage).toInt();
    }
  }

  Future<void> getUsedMemorySize() async {
    if (GetPlatform.isAndroid) {
      var memory = await MemoryReader.memoryUsed;
      //print('Memory load ${memory.loadMem} %');
      currentMemory = (memory.loadMem ?? 0).toInt();
    } else if (GetPlatform.isIOS) {
      currentMemory = (await MemoryReader.totalUsagePercent).toInt();
      //print('Memory load $percent %');
    }
  }

  Future<Map<String, bool>> checkSend() async {
    var cpu = true;
    var memory = true;
    var battery = true;
    // check battery
    if (_config.batteryLevel != 0) {
      await getBetterLevel();
      battery = currentBattery >= _config.batteryLevel;
    }

    // check cpu load
    if (_config.cpu != 0) {
      await getCpu();
      cpu = currentCpu <= _config.cpu;
    }

    // check cpu load
    if (_config.memory != 0) {
      await getUsedMemorySize();
      memory = currentMemory <= _config.memory;
    }

    return {
      'cpu $currentCpu% > ${_config.cpu}': cpu,
      'memory $currentMemory% > ${_config.memory} ': memory,
      'battery $currentBattery% < ${_config.batteryLevel}': battery
    };
  }

  Future<void> getStorageSize() async {
    //var total = await DiskSpace.getTotalDiskSpace ?? 0;
    var free = await DiskSpacePlus.getFreeDiskSpace ?? 0;
    currentFreeSpace = free;

    //print('total : $total, free : $free, currentFreeSpace : $currentFreeSpace');
  }
}
